=== modified file 'drizzled/handler.h'
--- drizzled/handler.h	2009-10-04 00:23:00 +0000
+++ drizzled/handler.h	2009-10-08 00:37:31 +0000
@@ -883,8 +883,8 @@
                                 bool tmp_table, uint32_t select_field_count);
 
 bool mysql_recreate_table(Session *session, TableList *table_list);
-bool mysql_create_like_table(Session *session, TableList *table,
-                             TableList *src_table,
+bool mysql_create_like_table(Session* session, TableList* table, TableList* src_table,
+                             drizzled::message::Table& create_table_proto,
                              HA_CREATE_INFO *create_info);
 bool mysql_rename_table(drizzled::plugin::StorageEngine *base, const char *old_db,
                         const char * old_name, const char *new_db,

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-10-07 21:45:49 +0000
+++ drizzled/sql_table.cc	2009-10-08 00:37:31 +0000
@@ -2370,6 +2370,7 @@
 */
 
 bool mysql_create_like_table(Session* session, TableList* table, TableList* src_table,
+                             drizzled::message::Table& create_table_proto,
                              HA_CREATE_INFO *create_info)
 {
   Table *name_lock= 0;
@@ -2382,7 +2383,6 @@
   uint32_t not_used;
   message::Table src_proto;
 
-
   /*
     By opening source table we guarantee that it exists and no concurrent
     DDL operation will mess with it. Later we also take an exclusive
@@ -2397,6 +2397,7 @@
 
   strncpy(src_path, src_table->table->s->path.str, sizeof(src_path));
 
+
   /*
     Check that destination tables does not exist. Note that its name
     was already checked when it was added to the table list.
@@ -2433,14 +2434,13 @@
     during the call to StorageEngine::createTable(). See bug #28614 for more info.
   */
   pthread_mutex_lock(&LOCK_open); /* We lock for CREATE TABLE LIKE to copy table definition */
-
   {
     int protoerr= EEXIST;
 
     if (src_table->schema_table)
     {
       if (mysql_create_like_schema_frm(session, src_table, create_info,
-                                     &src_proto))
+                                       &src_proto))
       {
         pthread_mutex_unlock(&LOCK_open);
         goto err;
@@ -2451,6 +2451,16 @@
       protoerr= plugin::StorageEngine::getTableProto(src_path, &src_proto);
     }
 
+    message::Table new_proto(src_proto);
+
+    if (create_info->used_fields & HA_CREATE_USED_ENGINE)
+    {
+      message::Table::StorageEngine *protoengine;
+
+      protoengine= new_proto.mutable_engine();
+      protoengine->set_name(create_table_proto.engine().name());
+    }
+
     string dst_proto_path(dst_path);
     string file_ext = ".dfe";
 
@@ -2459,10 +2469,10 @@
     if (protoerr == EEXIST)
     {
       plugin::StorageEngine* engine= plugin::StorageEngine::findByName(session,
-                                                src_proto.engine().name());
+                                                                       new_proto.engine().name());
 
       if (engine->check_flag(HTON_BIT_HAS_DATA_DICTIONARY) == false)
-        protoerr= drizzle_write_proto_file(dst_proto_path.c_str(), &src_proto);
+        protoerr= drizzle_write_proto_file(dst_proto_path.c_str(), &new_proto);
       else
         protoerr= 0;
     }
@@ -2476,16 +2486,15 @@
       pthread_mutex_unlock(&LOCK_open);
       goto err;
     }
+
+    /*
+      As mysql_truncate don't work on a new table at this stage of
+      creation, instead create the table directly (for both normal
+      and temporary tables).
+    */
+    err= plugin::StorageEngine::createTable(session, dst_path, db, table_name, create_info, 
+                                            true, &new_proto);
   }
-
-  /*
-    As mysql_truncate don't work on a new table at this stage of
-    creation, instead create the table directly (for both normal
-    and temporary tables).
-  */
-
-  err= plugin::StorageEngine::createTable(session, dst_path, db, table_name, create_info, 
-                                          true, &src_proto);
   pthread_mutex_unlock(&LOCK_open);
 
   if (create_info->options & HA_LEX_CREATE_TMP_TABLE)

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2009-10-06 17:55:59 +0000
+++ drizzled/sql_yacc.yy	2009-10-08 00:37:31 +0000
@@ -1209,7 +1209,7 @@
           '(' create2a {}
         | opt_create_table_options
           create3 {}
-        | LIKE table_ident
+        | LIKE table_ident opt_create_table_options
           {
             Session *session= YYSession;
             LEX *lex= session->lex;

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2009-10-06 17:03:54 +0000
+++ drizzled/statement/create_table.cc	2009-10-08 00:37:31 +0000
@@ -56,6 +56,8 @@
     create_info.db_type= ha_default_storage_engine(session);
   }
 
+
+
   /* 
     Now we set the name in our Table proto so that it will match 
     create_info.db_type.
@@ -67,6 +69,7 @@
     protoengine->set_name(create_info.db_type->getName());
   }
 
+
   /* If CREATE TABLE of non-temporary table, do implicit commit */
   if (! (create_info.options & HA_LEX_CREATE_TMP_TABLE))
   {
@@ -108,6 +111,7 @@
     session->lex->link_first_table_back(create_table, link_to_local);
     return true;
   }
+
   if (select_lex->item_list.elements)		// With select
   {
     select_result *result;
@@ -176,12 +180,14 @@
     /* So that CREATE TEMPORARY TABLE gets to binlog at commit/rollback */
     if (create_info.options & HA_LEX_CREATE_TMP_TABLE)
       session->options|= OPTION_KEEP_LOG;
+
     /* regular create */
     if (create_info.options & HA_LEX_CREATE_TABLE_LIKE)
     {
       res= mysql_create_like_table(session, 
                                    create_table, 
                                    select_tables,
+                                   create_table_proto,
                                    &create_info);
     }
     else

